@@ -7,8 +7,9 @@ from omegaconf import OmegaConf
 from time import sleep
 from memoization import cached
 import os
-load_dotenv()
 
+env_path = os.path.abspath('.env')
+load_dotenv(dotenv_path=env_path)
 
 def __connect_to_kubernetes():
   try:
