@@ -104,7 +104,7 @@ def get_http_handlers(descriptor: FileDescriptor, service_name: str, method: str
     if len(await request.body()) > 0:
       body = await request.json()
     input = {**request.path_params, **request.query_params, **body}
-    metadata = None
+    metadata = {}
     if 'Authorization' not in request.headers:
       logging.warn('no authorization header')
     else:
