@@ -9,7 +9,7 @@ from delphai_utils.config import get_config
 public_keys = {}
 
 # endpoint for getting all enabled JWKs
-base_url = get_config('keycloak.base_url') or 'https://auth.delphai.red'
+base_url = get_config('keycloak.base_url') or 'https://auth.delphai.com'
 url = f'{base_url}/auth/realms/delphai/protocol/openid-connect/certs'
 
 
